@@ -1,4 +1,4 @@
-from mvcbotbase import social_network_provider_implementations
+from mvcbotbase import social_network_provider_implementations, command_info
 from mvcbotbase.classes_for_command_arguments import (
     BaseArg, IntArg, WordArg, StringArg, Sequence
 )
